==> nextcloud-31.0.2-2-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/lv.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Norādītais operators ir nederīgs",
    "The given regular expression is invalid" : "Norādītā regulārā izteiksme nav derīga.",
    "The given file size is invalid" : "Norādītais datnes formāts nav derīgs",
    "The given tag id is invalid" : "Norādītais birkas id ir nederīgs",
    "The given IP range is invalid" : "Norādītais IP diapazons ir nederīgs",
    "The given IP range is not valid for IPv4" : "Norādītais IP diapazons nav derīgs IPv4",
    "The given IP range is not valid for IPv6" : "Norādītais IP diapazons nav derīgs IPv6",
    "The given time span is invalid" : "Norādītais laiks nav derīgs.",
    "The given start time is invalid" : "Dotais sākuma laiks ir nederīgs",
    "The given end time is invalid" : "Norādītais beigu laiks nav derīgs.",
    "The given group does not exist" : "Norādītā grupa nepastāv.",
    "File" : "Datne",
    "Operation #%s does not exist" : "Operation #%s does not exist",
    "Operation %s does not exist" : "Darbība %s nepastāv",
    "Operation %s is invalid" : "Darbība %s ir nederīga",
    "Check %s does not exist" : "Pārbaude %s nepastāv",
    "Check %s is invalid" : "Pārbaude %s ir nederīga",
    "Check #%s does not exist" : "Pārbaude #%s nepastāv",
    "Check %s is invalid or does not exist" : "Pārbaude %s ir nederīga vai nepastāv",
    "Flow" : "Plūsma",
    "Nextcloud workflow engine" : "Nextcloud darbplūsmu dzinis",
    "Folder" : "Mape",
    "Images" : "Attēli",
    "Files WebDAV" : "WebDAV datnes",
    "Android client" : "Android klients",
    "iOS client" : "iOS klients",
    "Desktop client" : "Darbvirsmas klients",
    "Select groups" : "Izvēlieties grupas",
    "Groups" : "Grupas",
    "Add new flow" : "Pievienot jaunu plūsmu",
    "Save" : "Saglabāt",
    "Cancel" : "Atcelt",
    "Delete" : "Dzēst",
    "Available flows" : "Pieejamās plūsmas",
    "No flows installed" : "Nav uzstādītu plūsmu",
    "More flows" : "Vairāk plūsmu",
    "Show more" : "Parādīt vairāk",
    "matches" : "atbilst",
    "does not match" : "neatbilst",
    "is" : "ir",
    "is not" : "nav",
    "File name" : "Datnes nosaukums",
    "File MIME type" : "Datnes MIME veids",
    "File size (upload)" : "Datnes lielums (augšupielādēt)",
    "less" : "mazāk",
    "less or equals" : "mazāks vai vienāds ar",
    "greater or equals" : "lielāks vai vienāds ar",
    "greater" : "lielāks",
    "Request remote address" : "Pieprasīt attālo adresi",
    "matches IPv4" : "atbilst IPv4",
    "does not match IPv4" : "neatbilst IPv4",
    "matches IPv6" : "atbilst IPv6",
    "does not match IPv6" : "neatbilst IPv6",
    "File system tag" : "Datņu sistēmas birka",
    "is tagged with" : "atzīmēts ar",
    "is not tagged with" : "nav atzīmēts ar",
    "Request URL" : "Pieprasījuma URL",
    "Request time" : "Pieprasījuma laiks",
    "between" : "starp",
    "not between" : "nav starp",
    "Request user agent" : "Nepieciešams lietotāja aģents",
    "is member of" : "ir biedrs",
    "is not member of" : "nav biedrs"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-31.0.9-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/workflowengine/l10n/lv.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "Norādītais operators ir nederīgs",
    "The given regular expression is invalid" : "Norādītā regulārā izteiksme nav derīga.",
    "The given file size is invalid" : "Norādītais datnes formāts nav derīgs",
    "The given tag id is invalid" : "Norādītais birkas id ir nederīgs",
    "The given IP range is invalid" : "Norādītais IP diapazons ir nederīgs",
    "The given IP range is not valid for IPv4" : "Norādītais IP diapazons nav derīgs IPv4",
    "The given IP range is not valid for IPv6" : "Norādītais IP diapazons nav derīgs IPv6",
    "The given time span is invalid" : "Norādītais laiks nav derīgs.",
    "The given start time is invalid" : "Dotais sākuma laiks ir nederīgs",
    "The given end time is invalid" : "Norādītais beigu laiks nav derīgs.",
    "The given group does not exist" : "Norādītā grupa nepastāv.",
    "File" : "Datne",
    "File renamed" : "Datne pārdēvēta",
    "%s renamed %s" : "%s pārdēvēja %s",
    "Operation #%s does not exist" : "Operation #%s does not exist",
    "Operation %s does not exist" : "Darbība %s nepastāv",
    "Operation %s is invalid" : "Darbība %s ir nederīga",
    "Check %s does not exist" : "Pārbaude %s nepastāv",
    "Check %s is invalid" : "Pārbaude %s ir nederīga",
    "Check #%s does not exist" : "Pārbaude #%s nepastāv",
    "Check %s is invalid or does not exist" : "Pārbaude %s ir nederīga vai nepastāv",
    "Flow" : "Plūsma",
    "Nextcloud workflow engine" : "Nextcloud darbplūsmu dzinis",
    "Folder" : "Mape",
    "Images" : "Attēli",
    "Files WebDAV" : "Datņu WebDAV",
    "Android client" : "Android klients",
    "iOS client" : "iOS klients",
    "Desktop client" : "Darbvirsmas klients",
    "Select groups" : "Atlasīt grupas",
    "Groups" : "Grupas",
    "Add new flow" : "Pievienot jaunu plūsmu",
    "Save" : "Saglabāt",
    "Cancel" : "Atcelt",
    "Delete" : "Izdzēst",
    "Available flows" : "Pieejamās plūsmas",
    "No flows installed" : "Nav uzstādītu plūsmu",
    "More flows" : "Vairāk plūsmu",
    "Show more" : "Parādīt vairāk",
    "matches" : "atbilst",
    "does not match" : "neatbilst",
    "is" : "ir",
    "is not" : "nav",
    "File name" : "Datnes nosaukums",
    "File MIME type" : "Datnes MIME veids",
    "File size (upload)" : "Datnes lielums (augšupielādēt)",
    "less" : "mazāk",
    "less or equals" : "mazāks vai vienāds ar",
    "greater or equals" : "lielāks vai vienāds ar",
    "greater" : "lielāks",
    "Request remote address" : "Pieprasīt attālo adresi",
    "matches IPv4" : "atbilst IPv4",
    "does not match IPv4" : "neatbilst IPv4",
    "matches IPv6" : "atbilst IPv6",
    "does not match IPv6" : "neatbilst IPv6",
    "File system tag" : "Datņu sistēmas birka",
    "is tagged with" : "atzīmēts ar",
    "is not tagged with" : "nav atzīmēts ar",
    "Request URL" : "Pieprasījuma URL",
    "Request time" : "Pieprasījuma laiks",
    "between" : "starp",
    "not between" : "nav starp",
    "Request user agent" : "Nepieciešams lietotāja aģents",
    "is member of" : "ir biedrs",
    "is not member of" : "nav dalībnieks"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
